buildbot-washer |license| |pyver| |version| |tests| |coverage|
==============================================================

|logo|

Buildbot Utility Library

.. |logo| image:: https://raw.githubusercontent.com/BBVA/buildbot-washer/develop/logo.png
.. |license| image:: https://img.shields.io/pypi/l/buildbot-washer.svg
.. |pyver| image:: https://img.shields.io/pypi/pyversions/buildbot-washer.svg
.. |version| image:: https://img.shields.io/pypi/v/buildbot-washer.svg
.. |tests| image:: https://img.shields.io/travis/BBVA/buildbot-washer.svg
.. |coverage| image:: https://img.shields.io/codecov/c/github/codecov/buildbot-washer.svg
